import type { OperationObject } from 'openapi3-ts';
import { APIDataType } from './serviceGenerator';
export declare type GenerateProps = {
    /**
     * 默认ts
     */
    genType?: 'ts' | 'js';
    /**
     * genType === js 生成 d.ts 文件 declaration
     */
    declaration?: boolean;
    requestLibPath?: string;
    requestImportStatement?: string;
    /**
     * api 的前缀
     */
    apiPrefix?: string | ((params: {
        path: string;
        method: string;
        namespace: string;
        functionName: string;
        autoExclude?: boolean;
    }) => string);
    /**
     * 生成的文件夹的路径
     */
    serversPath?: string;
    /**
     * Swagger 2.0 或 OpenAPI 3.0 的地址
     */
    schemaPath?: string;
    /**
     * 项目名称
     */
    hook?: {
        /** 自定义函数名称 */
        customFunctionName?: (data: OperationObject) => string;
        /** 自定义类型名称 */
        customTypeName?: (data: OperationObject) => string;
        /** 自定义类名 */
        customClassName?: (tagName: string) => string;
        /**
         * 自定义过滤器
         */
        customeFilter?: (api: APIDataType) => boolean;
        /**
         * 自定义请求function
         */
        customeFunctionBody?: (data: {
            namespace: string;
            api: APIDataType;
        }) => string;
        /**自定义相对 serversPath 的路径, 仅在 single 模式生效*/
        customeAbsolutePath?: (data: OperationObject) => string;
    };
    /**
     * 生成 [namespace].d.ts 默认为API
     */
    namespace?: string;
    /**
     * 默认为false，true时使用null代替可选
     */
    nullable?: boolean;
    mockFolder?: string;
    /**
     * 模板文件的文件路径
     */
    templatesFolder?: string;
    /**
     * 枚举样式
     */
    enumStyle?: 'string-literal' | 'enum';
    /**
     * 单接口 单文件
     * 比较便于多分支协作开发
     */
    single?: boolean;
    /**
     * 是否需要 index文件统一导出，默认不需要，方便做tree-shaking
     */
    ableCombineIndex?: boolean;
};
export declare const getSchema: (schemaPath: string) => Promise<any>;
export declare const generate: ({ requestLibPath, schemaPath, mockFolder, nullable, ...rest }: GenerateProps) => Promise<void>;
